ConstructorSpec

Struct ConstructorSpec 

pub struct ConstructorSpec<F: Form = MetaForm> {
    pub name: Vec<F::String>,
    pub selector: Selector,
    pub args: Vec<MessageParamSpec<F>>,
    pub docs: Vec<F::String>,
}
Describes a constructor of a contract.

Fields

name: Vec<F::String>

The name of the message.

In case of a trait provided constructor the trait name is prefixed.

selector: Selector

The selector hash of the message.

args: Vec<MessageParamSpec<F>>

The parameters of the deploy handler.

docs: Vec<F::String>

The deploy handler documentation.

Implementations

Source

impl<F> ConstructorSpec<F>
where F: Form,

pub fn name(&self) -> &[F::String]

Returns the name of the message.

In case of a trait provided constructor the trait name is prefixed.

pub fn selector(&self) -> &Selector

Returns the selector hash of the message.

pub fn args(&self) -> &[MessageParamSpec<F>]

Returns the parameters of the deploy handler.

pub fn docs(&self) -> &[F::String]

Returns the deploy handler documentation.

Source

impl ConstructorSpec

pub fn from_name( name: &'static str, ) -> ConstructorSpecBuilder<Missing<Selector>>

Creates a new constructor spec builder.

pub fn from_trait_and_name( trait_name: &'static str, constructor_name: &'static str, ) -> ConstructorSpecBuilder<Missing<Selector>>

Creates a new constructor spec builder for a trait provided constructor.