MessageSpec

Struct MessageSpec 

pub struct MessageSpec<F: Form = MetaForm> { /* private fields */ }
Describes a contract message.

Implementations

Source

impl MessageSpec

pub fn from_name( name: &'static str, ) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>

Creates a new message spec builder.

pub fn from_trait_and_name( trait_name: &'static str, message_name: &'static str, ) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>

Creates a new message spec builder for a trait provided message.

Source

impl<F> MessageSpec<F>
where F: Form,

pub fn name(&self) -> &[F::String]

Returns the name of the message and some optional prefixes.

In case of trait provided messages and constructors the prefix by convention in pro! is the name of the trait.

pub fn selector(&self) -> &Selector

Returns the selector hash of the message.

pub fn mutates(&self) -> bool

Returns true if the message is allowed to mutate the contract state.

pub fn payable(&self) -> bool

Returns true if the message is payable by the caller.

pub fn args(&self) -> &[MessageParamSpec<F>]

Returns the parameters of the message.

pub fn return_type(&self) -> &ReturnTypeSpec<F>

Returns the return type of the message.

pub fn docs(&self) -> &[F::String]

Returns the message documentation.