pub struct ConstructorSpec<F: Form = MetaForm> {
pub name: Vec<F::String>,
pub selector: Selector,
pub args: Vec<MessageParamSpec<F>>,
pub docs: Vec<F::String>,
}Expand description
Describes a constructor of a contract.
Fields
name: Vec<F::String>The name of the message.
In case of a trait provided constructor the trait name is prefixed.
selector: SelectorThe selector hash of the message.
args: Vec<MessageParamSpec<F>>The parameters of the deploy handler.
docs: Vec<F::String>The deploy handler documentation.
Implementations
Sourceimpl<F> ConstructorSpec<F>where
F: Form,
impl<F> ConstructorSpec<F>where
F: Form,
Sourceimpl ConstructorSpec
impl ConstructorSpec
Sourcepub fn from_name(
name: &'static str,
) -> ConstructorSpecBuilder<Missing<Selector>>
pub fn from_name( name: &'static str, ) -> ConstructorSpecBuilder<Missing<Selector>>
Creates a new constructor spec builder.
Sourcepub fn from_trait_and_name(
trait_name: &'static str,
constructor_name: &'static str,
) -> ConstructorSpecBuilder<Missing<Selector>>
pub fn from_trait_and_name( trait_name: &'static str, constructor_name: &'static str, ) -> ConstructorSpecBuilder<Missing<Selector>>
Creates a new constructor spec builder for a trait provided constructor.