pub struct MessageSpec<F: Form = MetaForm> { /* private fields */ }Expand description
Describes a contract message.
Implementations
Sourceimpl MessageSpec
impl MessageSpec
Sourcepub fn from_name(
name: &'static str,
) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>
pub fn from_name( name: &'static str, ) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>
Creates a new message spec builder.
Sourcepub fn from_trait_and_name(
trait_name: &'static str,
message_name: &'static str,
) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>
pub fn from_trait_and_name( trait_name: &'static str, message_name: &'static str, ) -> MessageSpecBuilder<Missing<Selector>, Missing<Mutates>, Missing<IsPayable>, Missing<Returns>>
Creates a new message spec builder for a trait provided message.
Sourceimpl<F> MessageSpec<F>where
F: Form,
impl<F> MessageSpec<F>where
F: Form,
Sourcepub fn name(&self) -> &[F::String]
pub fn name(&self) -> &[F::String]
Returns the name of the message and some optional prefixes.
In case of trait provided messages and constructors the prefix by convention in pro! is the name of the trait.
Sourcepub fn mutates(&self) -> bool
pub fn mutates(&self) -> bool
Returns true if the message is allowed to mutate the contract state.
Sourcepub fn args(&self) -> &[MessageParamSpec<F>]
pub fn args(&self) -> &[MessageParamSpec<F>]
Returns the parameters of the message.
Sourcepub fn return_type(&self) -> &ReturnTypeSpec<F>
pub fn return_type(&self) -> &ReturnTypeSpec<F>
Returns the return type of the message.